@@ -25,4 +25,12 @@
 #' @format An \code{sf} object.
 #' @examples
 #' example_sf_point
-"example_sf_point"
\ No newline at end of file
+"example_sf_point"
+
+#' @title Example stars object.
+#' @description Example stars object.
+#' @format A \code{stars} object.
+#' @examples
+#' library(stars)
+#' example_stars
+"example_stars"
