@@ -14,7 +14,7 @@
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
-#' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
+#' @param x_na_rm TRUE or FALSE of whether to include x_var NA values. Defaults to FALSE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 6. 
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
@@ -25,7 +25,7 @@
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param y_labels A function or named vector to modify y scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
-#' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
+#' @param y_na_rm TRUE or FALSE of whether to include y_var NA values. Defaults to FALSE.
 #' @param y_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
 #' @param y_title y scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
@@ -68,7 +68,7 @@ gg_line <- function(data,
                     x_balance = FALSE,
                     x_expand = NULL,
                     x_labels = NULL,
-                    x_na = TRUE,
+                    x_na_rm = FALSE,
                     x_pretty_n = 6,
                     x_rev = FALSE,
                     x_title = NULL,
@@ -79,7 +79,7 @@ gg_line <- function(data,
                     y_expand = NULL,
                     y_gridlines_minor = FALSE,
                     y_labels = scales::comma,
-                    y_na = TRUE,
+                    y_na_rm = FALSE,
                     y_pretty_n = 5,
                     y_title = NULL,
                     y_title_wrap = 50,
@@ -99,11 +99,11 @@ gg_line <- function(data,
   y_var <- rlang::enquo(y_var) #numeric var
   text_var <- rlang::enquo(text_var)
   
-  if (x_na == FALSE) {
+  if (x_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!x_var))
   }
-  if (y_na == FALSE) {
+  if (y_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!y_var))
   }
@@ -288,7 +288,7 @@ gg_line <- function(data,
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
-#' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
+#' @param x_na_rm TRUE or FALSE of whether to include x_var NA values. Defaults to FALSE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 6. 
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
@@ -299,7 +299,7 @@ gg_line <- function(data,
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param y_labels A function or named vector to modify y scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
-#' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
+#' @param y_na_rm TRUE or FALSE of whether to include y_var NA values. Defaults to FALSE.
 #' @param y_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
 #' @param y_title y scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
@@ -307,7 +307,7 @@ gg_line <- function(data,
 #' @param y_zero For a numeric y variable, TRUE or FALSE of whether the minimum of the y scale is zero. Defaults to TRUE.
 #' @param y_zero_line For a numeric y variable, TRUE or FALSE whether to add a zero reference line to the y scale. Defaults to TRUE if there are positive and negative values in y_var. Otherwise defaults to FALSE.  
 #' @param col_labels A function or named vector to modify colour scale labels. Use ggplot2::waiver() to keep colour labels untransformed. 
-#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_na_rm TRUE or FALSE of whether to include col_var NA values. Defaults to FALSE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. Not applicable where mobile equals TRUE.
 #' @param caption Caption title string. 
@@ -350,7 +350,7 @@ gg_line_col <- function(data,
                         x_balance = FALSE,
                         x_expand = NULL,
                         x_labels = NULL,
-                        x_na = TRUE,
+                        x_na_rm = FALSE,
                         x_pretty_n = 6,
                         x_rev = FALSE,
                         x_title = NULL,
@@ -361,7 +361,7 @@ gg_line_col <- function(data,
                         y_expand = NULL,
                         y_gridlines_minor = FALSE,
                         y_labels = scales::comma,
-                        y_na = TRUE,
+                        y_na_rm = FALSE,
                         y_pretty_n = 5,
                         y_title = NULL,
                         y_title_wrap = 50,
@@ -369,7 +369,7 @@ gg_line_col <- function(data,
                         y_zero = FALSE,
                         y_zero_line = NULL,
                         col_labels = stringr::str_to_sentence,
-                        col_na = TRUE,
+                        col_na_rm = FALSE,
                         col_title = NULL,
                         col_title_wrap = 25,
                         caption = NULL,
@@ -385,15 +385,15 @@ gg_line_col <- function(data,
   col_var <- rlang::enquo(col_var) #categorical var
   text_var <- rlang::enquo(text_var)
   
-  if (x_na == FALSE) {
+  if (x_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!x_var))
   }
-  if (y_na == FALSE) {
+  if (y_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!y_var))
   }
-  if (col_na == FALSE) {
+  if (col_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!col_var))
   }
@@ -610,7 +610,7 @@ gg_line_col <- function(data,
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
-#' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
+#' @param x_na_rm TRUE or FALSE of whether to include x_var NA values. Defaults to FALSE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 3. 
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
@@ -620,7 +620,7 @@ gg_line_col <- function(data,
 #' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
-#' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
+#' @param y_na_rm TRUE or FALSE of whether to include y_var NA values. Defaults to FALSE.
 #' @param y_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 4. 
 #' @param y_title y scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
@@ -628,7 +628,7 @@ gg_line_col <- function(data,
 #' @param y_zero For a numeric y variable, TRUE or FALSE of whether the minimum of the y scale is zero. Defaults to TRUE.
 #' @param y_zero_line For a numeric y variable, TRUE or FALSE whether to add a zero reference line to the y scale. Defaults to TRUE if there are positive and negative values in y_var. Otherwise defaults to FALSE.  
 #' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
-#' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
+#' @param facet_na_rm TRUE or FALSE of whether to include facet_var NA values. Defaults to FALSE.
 #' @param facet_ncol The number of columns of facetted plots. 
 #' @param facet_nrow The number of rows of facetted plots. 
 #' @param facet_scales Whether facet_scales should be "fixed" across facets, "free" in both directions, or free in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed".
@@ -669,7 +669,7 @@ gg_line_facet <- function(data,
                           x_balance = FALSE,
                           x_expand = NULL,
                           x_labels = NULL,
-                          x_na = TRUE,
+                          x_na_rm = FALSE,
                           x_pretty_n = 3,
                           x_rev = FALSE,
                           x_title = NULL,
@@ -680,7 +680,7 @@ gg_line_facet <- function(data,
                           y_expand = NULL,
                           y_gridlines_minor = FALSE,
                           y_labels = scales::comma,
-                          y_na = TRUE,
+                          y_na_rm = FALSE,
                           y_pretty_n = 4,
                           y_title = NULL,
                           y_title_wrap = 50,
@@ -688,7 +688,7 @@ gg_line_facet <- function(data,
                           y_zero = FALSE,
                           y_zero_line = NULL,
                           facet_labels = stringr::str_to_sentence,
-                          facet_na = TRUE,
+                          facet_na_rm = FALSE,
                           facet_ncol = NULL,
                           facet_nrow = NULL,
                           facet_scales = "fixed",
@@ -705,15 +705,15 @@ gg_line_facet <- function(data,
   facet_var <- rlang::enquo(facet_var) #categorical var
   text_var <- rlang::enquo(text_var)
   
-  if (x_na == FALSE) {
+  if (x_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!x_var))
   }
-  if (y_na == FALSE) {
+  if (y_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!y_var))
   }
-  if (facet_na == FALSE) {
+  if (facet_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!facet_var))
   }
@@ -901,7 +901,7 @@ gg_line_facet <- function(data,
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
-#' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
+#' @param x_na_rm TRUE or FALSE of whether to include x_var NA values. Defaults to FALSE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 3. 
 #' @param x_rev For a categorical x variable, TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
@@ -912,7 +912,7 @@ gg_line_facet <- function(data,
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param y_labels A function or named vector to modify y scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
-#' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
+#' @param y_na_rm TRUE or FALSE of whether to include y_var NA values. Defaults to FALSE.
 #' @param y_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 4. 
 #' @param y_title y scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
@@ -920,11 +920,11 @@ gg_line_facet <- function(data,
 #' @param y_zero For a numeric y variable, TRUE or FALSE of whether the minimum of the y scale is zero. Defaults to TRUE.
 #' @param y_zero_line For a numeric y variable, TRUE or FALSE whether to add a zero reference line to the y scale. Defaults to TRUE if there are positive and negative values in y_var. Otherwise defaults to FALSE.  
 #' @param col_labels A function or named vector to modify colour scale labels. Use ggplot2::waiver() to keep colour labels untransformed. 
-#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_na_rm TRUE or FALSE of whether to include col_var NA values. Defaults to FALSE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. 
 #' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
-#' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
+#' @param facet_na_rm TRUE or FALSE of whether to include facet_var NA values. Defaults to FALSE.
 #' @param facet_ncol The number of columns of facetted plots.  
 #' @param facet_nrow The number of rows of facetted plots.  
 #' @param facet_scales Whether facet_scales should be "fixed" across facets, "free" in both directions, or free in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed".
@@ -969,7 +969,7 @@ gg_line_col_facet <- function(data,
                               x_balance = FALSE,
                               x_expand = NULL,
                               x_labels = NULL,
-                              x_na = TRUE,
+                              x_na_rm = FALSE,
                               x_pretty_n = 3,
                               x_rev = FALSE,
                               x_title = NULL,
@@ -980,7 +980,7 @@ gg_line_col_facet <- function(data,
                               y_expand = NULL,
                               y_gridlines_minor = FALSE,
                               y_labels = scales::comma,
-                              y_na = TRUE,
+                              y_na_rm = FALSE,
                               y_pretty_n = 4,
                               y_trans = "identity",
                               y_title = NULL,
@@ -988,11 +988,11 @@ gg_line_col_facet <- function(data,
                               y_zero = FALSE,
                               y_zero_line = NULL,
                               col_labels = stringr::str_to_sentence,
-                              col_na = TRUE,
+                              col_na_rm = FALSE,
                               col_title = NULL,
                               col_title_wrap = 25,
                               facet_labels = stringr::str_to_sentence,
-                              facet_na = TRUE,
+                              facet_na_rm = FALSE,
                               facet_ncol = NULL,
                               facet_nrow = NULL,
                               facet_scales = "fixed",
@@ -1009,19 +1009,19 @@ gg_line_col_facet <- function(data,
   facet_var <- rlang::enquo(facet_var) #categorical var
   text_var <- rlang::enquo(text_var)
   
-  if (x_na == FALSE) {
+  if (x_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!x_var))
   }
-  if (y_na == FALSE) {
+  if (y_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!y_var))
   }
-  if (col_na == FALSE) {
+  if (col_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!col_var))
   }
-  if (facet_na == FALSE) {
+  if (facet_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!facet_var))
   }
