@@ -7,8 +7,8 @@
 #' @param alpha The opacity of features. Defaults to 1 for points/lines, or 0.5 for polygons.
 #' @param pal Character vector of hex codes. 
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
-#' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
+#' @param borders_on_top TRUE or FALSE  as to whether the borders are on top of the sf object supplied to the data argument. Defaults to TRUE for points and lines, but FALSE for polygons..
+#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
@@ -33,8 +33,8 @@ gg_sf <- function(data,
                   alpha = NULL,
                   pal = NULL,
                   borders = NULL,
-                  borders_behind = TRUE,
-                  pal_borders = "#7F7F7F",
+                  borders_on_top = NULL,
+                  borders_pal = "#7F7F7F",
                   borders_size = 0.2,
                   title = NULL,
                   title_wrap = 80,
@@ -52,8 +52,27 @@ gg_sf <- function(data,
   text_var <- rlang::enquo(text_var)
   
   if (class(data)[1] != "sf") stop("Please use an sf object as data input")
-  if (is.na(sf::st_crs(data))) stop("Please assign a coordinate reference system")
+  if (is.na(sf::st_crs(data)$proj4string)) stop("Please assign a coordinate reference system to data input")
   
+  if (!is.null(borders)) {
+    if (class(borders)[1] != "sf") stop("Please use an sf object as borders input")
+    if (is.na(sf::st_crs(borders)$proj4string)) stop("Please assign a coordinate reference system to borders object")
+  }
+  
+  geometry_type <- unique(sf::st_geometry_type(data))
+  
+  if (!geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING", "POLYGON", "MULTIPOLYGON")) {
+    stop("Please use an sf object with geometry type of POINT, MULTIPOINT, LINESTRING, MULTILINESTRING, POLYGON, MULTIPOLYGON")
+  }
+
+  if (is.null(borders_on_top)) {
+    if (geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING")) {
+      borders_on_top <- FALSE
+    } else ({
+      borders_on_top <- TRUE
+    })
+  }
+
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
@@ -63,15 +82,15 @@ gg_sf <- function(data,
       font_size_body = font_size_body,
       font_size_title = font_size_title
     )
-  
+
   if (!is.null(borders)) {
-    if (sf::st_is_longlat(data) == FALSE) borders <- sf::st_transform(borders, sf::st_crs(data))
-    if (borders_behind == TRUE) {
+    if (sf::st_crs(data) != sf::st_crs(borders)) borders <- sf::st_transform(borders, sf::st_crs(data))
+    if (borders_on_top == FALSE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -80,19 +99,19 @@ gg_sf <- function(data,
   if (is.null(pal)) pal <- pal_viridis_reorder(1)
   else pal <- pal[1]
   
-  if (unique(sf::st_geometry_type(data)) %in% c("POINT", "MULTIPOINT")) {
+  if (geometry_type %in% c("POINT", "MULTIPOINT")) {
     if(is.null(alpha)) alpha <- 1
     
     plot <- plot +
       geom_sf(aes(text = !!text_var), size = size_point, col = pal, alpha = alpha)
   }
-  else if (unique(sf::st_geometry_type(data)) %in% c("LINESTRING", "MULTILINESTRING")) {
+  else if (geometry_type %in% c("LINESTRING", "MULTILINESTRING")) {
     if(is.null(alpha)) alpha <- 1
     
     plot <- plot +
       geom_sf(aes(text = !!text_var), size = size_line, col = pal, alpha = alpha)
   }
-  else if (unique(sf::st_geometry_type(data)) %in% c("POLYGON", "MULTIPOLYGON")) {
+  else if (geometry_type %in% c("POLYGON", "MULTIPOLYGON")) {
     if(is.null(alpha)) alpha <- 0.5
     
     plot <- plot +
@@ -105,12 +124,12 @@ gg_sf <- function(data,
   }
   
   if (!is.null(borders)) {
-    if (borders_behind == FALSE) {
+    if (borders_on_top == TRUE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -149,18 +168,19 @@ gg_sf <- function(data,
 #' @param size_line Size of lines. Defaults to 0.5.
 #' @param alpha The opacity of features. Defaults to 1 for points/lines, or 0.95 for polygons.
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
-#' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
+#' @param borders_on_top TRUE or FALSE  as to whether the borders are on top of the sf object supplied to the data argument. Defaults to TRUE for points and lines, but FALSE for polygons..
+#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 75. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
+#' @param col_label_digits If numeric colour method, the number of digits to round the labels to. Only applicable where col_labels equals NULL.
 #' @param col_labels A function or named vector to modify colour scale labels. Defaults to stringr::str_to_sentence for categorical colour variables and scales::comma for numeric colour variables. Use ggplot2::waiver() to keep colour labels untransformed.   
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "bin".
 #' @param col_pretty_n For a numeric colour variable of "bin" col_method, the desired number of intervals on the colour scale, as calculated by the pretty algorithm. Defaults to 5. 
-#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_na_rm TRUE or FALSE of whether to include col_var NA values. Defaults to FALSE.
 #' @param col_right_closed For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. Not applicable where mobile equals TRUE.
@@ -199,16 +219,17 @@ gg_sf_col <- function(data,
                       size_line = 0.5,
                       alpha = NULL,
                       borders = NULL,
-                      borders_behind = TRUE,
-                      pal_borders = "#7F7F7F",
+                      borders_on_top = NULL,
+                      borders_pal = "#7F7F7F",
                       borders_size = 0.2,
                       title = NULL,
                       title_wrap = 80,
                       subtitle = NULL,
                       subtitle_wrap = 80,
                       col_cuts = NULL,
+                      col_label_digits = NULL,
                       col_labels = NULL,
-                      col_na = TRUE,
+                      col_na_rm = FALSE,
                       col_pretty_n = 5,
                       col_method = NULL,
                       col_right_closed = TRUE,
@@ -226,7 +247,7 @@ gg_sf_col <- function(data,
   col_var <- rlang::enquo(col_var)
   text_var <- rlang::enquo(text_var)
   
-  if (col_na == FALSE) {
+  if (col_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!col_var))
   }
@@ -234,7 +255,12 @@ gg_sf_col <- function(data,
   col_var_vctr <- dplyr::pull(data, !!col_var)
   
   if (class(data)[1] != "sf") stop("Please use an sf object as data input")
-  if (is.na(sf::st_crs(data))) stop("Please assign a coordinate reference system")
+  if (is.na(sf::st_crs(data)$proj4string)) stop("Please assign a coordinate reference system to data input")
+  
+  if (!is.null(borders)) {
+    if (class(borders)[1] != "sf") stop("Please use an sf object as borders input")
+    if (is.na(sf::st_crs(borders)$proj4string)) stop("Please assign a coordinate reference system to borders object")
+  }
   
   if(is.logical(col_var_vctr)) {
     data <- data %>% 
@@ -243,13 +269,25 @@ gg_sf_col <- function(data,
     col_var_vctr <- dplyr::pull(data, !!col_var)
   }
   
+  geometry_type <- unique(sf::st_geometry_type(data))
+  
+  if (!geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING", "POLYGON", "MULTIPOLYGON")) {
+    stop("Please use an sf object with geometry type of POINT, MULTIPOINT, LINESTRING, MULTILINESTRING, POLYGON, MULTIPOLYGON")
+  }
+  
+  if (is.null(borders_on_top)) {
+    if (geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING")) {
+      borders_on_top <- FALSE
+    } else ({
+      borders_on_top <- TRUE
+    })
+  }
+  
   if (is.null(col_title)) col_title <- snakecase::to_sentence_case(rlang::as_name(col_var))
   
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
-  geometry_type <- unique(sf::st_geometry_type(data))
-  
   plot <- ggplot(data) +
     theme_map(
       font_family = font_family,
@@ -258,13 +296,13 @@ gg_sf_col <- function(data,
     )
   
   if (!is.null(borders)) {
-    if (sf::st_is_longlat(data) == FALSE) borders <- sf::st_transform(borders, sf::st_crs(data))
-    if (borders_behind == TRUE) {
+    if (sf::st_crs(data) != sf::st_crs(borders)) borders <- sf::st_transform(borders, sf::st_crs(data))
+    if (borders_on_top == FALSE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -292,12 +330,19 @@ gg_sf_col <- function(data,
         if (dplyr::last(col_cuts) != Inf) warning("The last element of the col_cuts vector should generally be Inf")
       })
     }
-
-    if (is.null(col_labels)) col_labels <- scales::comma
     
+    if (is.null(col_labels)) {
+      if (is.null(col_label_digits)) {
+        col_labels <- scales::comma
+      }
+      else {
+        col_labels <- scales::comma_format(accuracy = 10 ^ -col_label_digits)
+      }
+    }
+
     if (is.function(col_labels)) {
       data <- data %>% 
-        dplyr::mutate(dplyr::across(!!col_var, ~kimisc::cut_format(.x, col_cuts, 
+        dplyr::mutate(dplyr::across(!!col_var, ~cut_format(.x, col_cuts, 
                                                                    right = col_right_closed, 
                                                                    include.lowest = TRUE, 
                                                                    dig.lab = 50, 
@@ -362,7 +407,6 @@ gg_sf_col <- function(data,
         aes(col = !!col_var, fill = !!col_var, text = !!text_var),
         alpha = alpha,
         size = size_line,
-        alpha = alpha,
         data = data
       )
   }
@@ -390,12 +434,12 @@ gg_sf_col <- function(data,
   }
   
   if (!is.null(borders)) {
-    if (borders_behind == FALSE) {
+    if (borders_on_top == TRUE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -436,12 +480,12 @@ gg_sf_col <- function(data,
 #' @param alpha The opacity of features. Defaults to 1 for points/lines, or 0.5 for polygons.
 #' @param pal Character vector of hex codes. 
 #' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
-#' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
+#' @param facet_na_rm TRUE or FALSE of whether to include facet_var NA values. Defaults to FALSE.
 #' @param facet_ncol The number of columns of facetted plots. 
 #' @param facet_nrow The number of rows of facetted plots. 
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
-#' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
+#' @param borders_on_top TRUE or FALSE  as to whether the borders are on top of the sf object supplied to the data argument. Defaults to TRUE for points and lines, but FALSE for polygons..
+#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. 
 #' @param subtitle Subtitle string. 
@@ -467,12 +511,12 @@ gg_sf_facet <- function(data,
                         alpha = NULL,
                         pal = NULL,
                         facet_labels = stringr::str_to_sentence,
-                        facet_na = TRUE,
+                        facet_na_rm = FALSE,
                         facet_ncol = NULL,
                         facet_nrow = NULL,
                         borders = NULL,
-                        borders_behind = TRUE,
-                        pal_borders = "#7F7F7F",
+                        borders_on_top = NULL,
+                        borders_pal = "#7F7F7F",
                         borders_size = 0.2,
                         title = NULL,
                         title_wrap = 80,
@@ -490,7 +534,7 @@ gg_sf_facet <- function(data,
   facet_var <- rlang::enquo(facet_var) #categorical var
   text_var <- rlang::enquo(text_var)
   
-  if (facet_na == FALSE) {
+  if (facet_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!facet_var))
   }
@@ -498,9 +542,14 @@ gg_sf_facet <- function(data,
   facet_var_vctr <- dplyr::pull(data, !!facet_var)
   
   if (class(data)[1] != "sf") stop("Please use an sf object as data input")
-  if (is.na(sf::st_crs(data))) stop("Please assign a coordinate reference system")
+  if (is.na(sf::st_crs(data)$proj4string)) stop("Please assign a coordinate reference system to data input")
   if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable")
   
+  if (!is.null(borders)) {
+    if (class(borders)[1] != "sf") stop("Please use an sf object as borders input")
+    if (is.na(sf::st_crs(borders)$proj4string)) stop("Please assign a coordinate reference system to borders object")
+  }
+  
   if(is.logical(facet_var_vctr)) {
     data <- data %>% 
       dplyr::mutate(dplyr::across(!!facet_var, ~factor(.x, levels = c("TRUE", "FALSE"))))
@@ -508,11 +557,23 @@ gg_sf_facet <- function(data,
     facet_var_vctr <- dplyr::pull(data, !!facet_var)
   }
   
+  geometry_type <- unique(sf::st_geometry_type(data))
+  
+  if (!geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING", "POLYGON", "MULTIPOLYGON")) {
+    stop("Please use an sf object with geometry type of POINT, MULTIPOINT, LINESTRING, MULTILINESTRING, POLYGON, MULTIPOLYGON")
+  }
+  
+  if (is.null(borders_on_top)) {
+    if (geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING")) {
+      borders_on_top <- FALSE
+    } else ({
+      borders_on_top <- TRUE
+    })
+  }
+  
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  geometry_type <- unique(sf::st_geometry_type(data))
-  
   plot <- ggplot(data) +
     theme_map(
       font_family = font_family,
@@ -521,13 +582,13 @@ gg_sf_facet <- function(data,
     )
   
   if (!is.null(borders)) {
-    if (sf::st_is_longlat(data) == FALSE) borders <- sf::st_transform(borders, sf::st_crs(data))
-    if (borders_behind == TRUE) {
+    if (sf::st_crs(data) != sf::st_crs(borders)) borders <- sf::st_transform(borders, sf::st_crs(data))
+    if (borders_on_top == FALSE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -570,18 +631,17 @@ gg_sf_facet <- function(data,
         fill = pal,
         alpha = alpha,
         size = size_line,
-        alpha = alpha,
         data = data
       )
   }
   
   if (!is.null(borders)) {
-    if (borders_behind == FALSE) {
+    if (borders_on_top == TRUE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -605,14 +665,14 @@ gg_sf_facet <- function(data,
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
 #' @param text_var Unquoted variable to be used as a customised tooltip in combination with plotly::ggplotly(plot, tooltip = "text"). Defaults to NULL.
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the colorbrewer Set1 or viridis.
-#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
 #' @param pal_na The hex code or name of the NA colour to be used.
 #' @param pal_rev Reverses the palette. Defaults to FALSE.
 #' @param size_point Size of points. Defaults to 0.5.
 #' @param size_line Size of lines. Defaults to 0.5.
 #' @param alpha The opacity of features. Defaults to 1 for points/lines, or 0.95 for polygons.
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
-#' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
+#' @param borders_on_top TRUE or FALSE  as to whether the borders are on top of the sf object supplied to the data argument. Defaults to TRUE for points and lines, but FALSE for polygons..
+#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. 
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
@@ -620,14 +680,15 @@ gg_sf_facet <- function(data,
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
 #' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
+#' @param col_label_digits If numeric colour method, the number of digits to round the labels to. Only applicable where col_labels equals NULL.
 #' @param col_labels A function or named vector to modify colour scale labels. Defaults to stringr::str_to_sentence for categorical colour variables and scales::comma for numeric colour variables. Use ggplot2::waiver() to keep colour labels untransformed.   
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "bin".
 #' @param col_pretty_n For a numeric colour variable of "bin" col_method, the desired number of intervals on the colour scale, as calculated by the pretty algorithm. Defaults to 5. 
-#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_na_rm TRUE or FALSE of whether to include col_var NA values. Defaults to FALSE.
 #' @param col_right_closed For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. 
-#' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
+#' @param facet_na_rm TRUE or FALSE of whether to include facet_var NA values. Defaults to FALSE.
 #' @param facet_nrow The number of rows of facetted plots.
 #' @param facet_ncol The number of columns of facetted plots.
 #' @param caption Caption title string. 
@@ -648,29 +709,30 @@ gg_sf_col_facet <- function(data,
                             facet_var,
                             text_var = NULL,
                             pal = NULL,
-                            pal_borders = "#7F7F7F",
                             pal_na = "#7F7F7F",
                             pal_rev = FALSE,
                             size_point = 1,
                             size_line = 0.5,
                             alpha = NULL,
                             borders = NULL,
-                            borders_behind = TRUE,
+                            borders_on_top = NULL,
+                            borders_pal = "#7F7F7F",
                             borders_size = 0.2,
                             title = NULL,
                             title_wrap = 80,
                             subtitle = NULL,
                             subtitle_wrap = 80,
                             col_cuts = NULL,
+                            col_label_digits = NULL,
                             col_labels = NULL,
                             col_method = NULL,
-                            col_na = TRUE,
+                            col_na_rm = FALSE,
                             col_pretty_n = 5,
                             col_right_closed = TRUE,
                             col_title = NULL,
                             col_title_wrap = 25,
                             facet_labels = stringr::str_to_sentence,
-                            facet_na = TRUE,
+                            facet_na_rm = FALSE,
                             facet_ncol = NULL,
                             facet_nrow = NULL,
                             caption = NULL,
@@ -685,11 +747,11 @@ gg_sf_col_facet <- function(data,
   facet_var <- rlang::enquo(facet_var) #categorical var
   text_var <- rlang::enquo(text_var)
   
-  if (col_na == FALSE) {
+  if (col_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!col_var))
   }
-  if (facet_na == FALSE) {
+  if (facet_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!facet_var))
   }
@@ -698,9 +760,14 @@ gg_sf_col_facet <- function(data,
   facet_var_vctr <- dplyr::pull(data, !!facet_var)
   
   if (class(data)[1] != "sf") stop("Please use an sf object as data input")
-  if (is.na(sf::st_crs(data))) stop("Please assign a coordinate reference system")
+  if (is.na(sf::st_crs(data)$proj4string)) stop("Please assign a coordinate reference system to data input")
   if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable")
   
+  if (!is.null(borders)) {
+    if (class(borders)[1] != "sf") stop("Please use an sf object as borders input")
+    if (is.na(sf::st_crs(borders)$proj4string)) stop("Please assign a coordinate reference system to borders object")
+  }
+  
   if(is.logical(col_var_vctr)) {
     data <- data %>% 
       dplyr::mutate(dplyr::across(!!col_var, ~factor(.x, levels = c("TRUE", "FALSE"))))
@@ -716,11 +783,23 @@ gg_sf_col_facet <- function(data,
   
   if (is.null(col_title)) col_title <- snakecase::to_sentence_case(rlang::as_name(col_var))
   
+  geometry_type <- unique(sf::st_geometry_type(data))
+  
+  if (!geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING", "POLYGON", "MULTIPOLYGON")) {
+    stop("Please use an sf object with geometry type of POINT, MULTIPOINT, LINESTRING, MULTILINESTRING, POLYGON, MULTIPOLYGON")
+  }
+  
+  if (is.null(borders_on_top)) {
+    if (geometry_type %in% c("POINT", "MULTIPOINT", "LINESTRING", "MULTILINESTRING")) {
+      borders_on_top <- FALSE
+    } else ({
+      borders_on_top <- TRUE
+    })
+  }
+  
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  geometry_type <- unique(sf::st_geometry_type(data))
-  
   plot <- ggplot(data) +
     theme_map(
       font_family = font_family,
@@ -729,13 +808,13 @@ gg_sf_col_facet <- function(data,
     )
   
   if (!is.null(borders)) {
-    if (sf::st_is_longlat(data) == FALSE) borders <- sf::st_transform(borders, sf::st_crs(data))
-    if (borders_behind == TRUE) {
+    if (sf::st_crs(data) != sf::st_crs(borders)) borders <- sf::st_transform(borders, sf::st_crs(data))
+    if (borders_on_top == FALSE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
@@ -764,11 +843,18 @@ gg_sf_col_facet <- function(data,
       })
     }
 
-    if (is.null(col_labels)) col_labels <- scales::comma
+    if (is.null(col_labels)) {
+      if (is.null(col_label_digits)) {
+        col_labels <- scales::comma
+      }
+      else {
+        col_labels <- scales::comma_format(accuracy = 10 ^ -col_label_digits)
+      }
+    }
     
     if (is.function(col_labels)) {
       data <- data %>% 
-        dplyr::mutate(dplyr::across(!!col_var, ~kimisc::cut_format(.x, col_cuts, 
+        dplyr::mutate(dplyr::across(!!col_var, ~cut_format(.x, col_cuts, 
                                                                    right = col_right_closed, 
                                                                    include.lowest = TRUE, 
                                                                    dig.lab = 50, 
@@ -858,12 +944,12 @@ gg_sf_col_facet <- function(data,
   }
   
   if (!is.null(borders)) {
-    if (borders_behind == FALSE) {
+    if (borders_on_top == TRUE) {
       plot <- plot +
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = pal_borders,
+          colour = borders_pal,
           fill = "transparent"
         )
     }
