@@ -20,20 +20,21 @@
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 60. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
-#' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
+#' @param x_na_rm TRUE or FALSE of whether to include x_var NA values. Defaults to FALSE.
 #' @param x_rev TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
-#' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
+#' @param y_na_rm TRUE or FALSE of whether to include y_var NA values. Defaults to FALSE.
 #' @param y_rev TRUE or FALSE of whether the y variable variable is reversed. Defaults to FALSE.
 #' @param y_title y scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles.
+#' @param col_label_digits If numeric colour method, the number of digits to round the labels to. Only applicable where col_labels equals NULL.
 #' @param col_labels A function or named vector to modify colour scale labels. Defaults to stringr::str_to_sentence for categorical colour variables and scales::comma for numeric colour variables. Use ggplot2::waiver() to keep colour labels untransformed.  
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "bin".
-#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_na_rm TRUE or FALSE of whether to include col_var NA values. Defaults to FALSE.
 #' @param col_pretty_n For a numeric colour variable of "bin" col_method, the desired number of intervals on the colour scale, as calculated by the pretty algorithm. Defaults to 5. 
 #' @param col_right_closed For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
@@ -82,20 +83,21 @@ gg_tile_col <- function(data,
                        subtitle_wrap = 75,
                        x_expand = c(0, 0),
                        x_labels = stringr::str_to_sentence,
-                       x_na = TRUE,
+                       x_na_rm = FALSE,
                        x_rev = FALSE,
                        x_title = NULL,
                        x_title_wrap = 50,
                        y_expand = c(0, 0),
                        y_labels = stringr::str_to_sentence,
-                       y_na = TRUE,
+                       y_na_rm = FALSE,
                        y_rev = FALSE,
                        y_title = NULL,
                        y_title_wrap = 50,
                        col_cuts = NULL,
+                       col_label_digits = NULL,
                        col_labels = NULL,
                        col_method = NULL,
-                       col_na = TRUE,
+                       col_na_rm = FALSE,
                        col_pretty_n = 5,
                        col_right_closed = TRUE,
                        col_title = NULL,
@@ -115,15 +117,15 @@ gg_tile_col <- function(data,
   label_var <- rlang::enquo(label_var)
   text_var <- rlang::enquo(text_var)
   
-  if (x_na == FALSE) {
+  if (x_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!x_var))
   }
-  if (y_na == FALSE) {
+  if (y_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!y_var))
   }
-  if (col_na == FALSE) {
+  if (col_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!col_var))
   }
@@ -208,11 +210,18 @@ gg_tile_col <- function(data,
       })
     }
     
-    if (is.null(col_labels)) col_labels <- scales::comma
-    
+    if (is.null(col_labels)) {
+      if (is.null(col_label_digits)) {
+        col_labels <- scales::comma
+      }
+      else {
+        col_labels <- scales::comma_format(accuracy = 10 ^ -col_label_digits)
+      }
+    }
+
     if (is.function(col_labels)) {
       data <- data %>% 
-        dplyr::mutate(dplyr::across(!!col_var, ~kimisc::cut_format(.x, col_cuts, 
+        dplyr::mutate(dplyr::across(!!col_var, ~cut_format(.x, col_cuts, 
                                                                    right = col_right_closed, 
                                                                    include.lowest = TRUE, 
                                                                    dig.lab = 50, 
@@ -333,26 +342,27 @@ gg_tile_col <- function(data,
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 60. 
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param x_labels A function or named vector to modify x scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
-#' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
+#' @param x_na_rm TRUE or FALSE of whether to include x_var NA values. Defaults to FALSE.
 #' @param x_rev TRUE or FALSE of whether the x variable variable is reversed. Defaults to FALSE.
 #' @param x_title X scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param x_title_wrap Number of characters to wrap the x title to. Defaults to 50. 
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
 #' @param y_labels A function or named vector to modify y scale labels. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
-#' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
+#' @param y_na_rm TRUE or FALSE of whether to include y_var NA values. Defaults to FALSE.
 #' @param y_rev TRUE or FALSE of whether the y variable variable is reversed. Defaults to FALSE.
 #' @param y_title y scale title string. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param y_title_wrap Number of characters to wrap the y title to. Defaults to 50. 
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles.
+#' @param col_label_digits If numeric colour method, the number of digits to round the labels to. Only applicable where col_labels equals NULL.
 #' @param col_labels A function or named vector to modify colour scale labels. Defaults to stringr::str_to_sentence for categorical colour variables and scales::comma for numeric colour variables. Use ggplot2::waiver() to keep colour labels untransformed.  
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "bin".
-#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_na_rm TRUE or FALSE of whether to include col_var NA values. Defaults to FALSE.
 #' @param col_pretty_n For a numeric colour variable of "bin" col_method, the desired number of intervals on the colour scale, as calculated by the pretty algorithm. Defaults to 5. 
 #' @param col_right_closed For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. Not applicable where mobile equals TRUE.
 #' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
-#' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
+#' @param facet_na_rm TRUE or FALSE of whether to include facet_var NA values. Defaults to FALSE.
 #' @param facet_ncol The number of columns of facetted plots. 
 #' @param facet_nrow The number of rows of facetted plots. 
 #' @param facet_scales Whether facet_scales should be "fixed" across facets, "free" in both directions, or free in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed".
@@ -380,7 +390,7 @@ gg_tile_col <- function(data,
 #'     col_var = bill_length_mm,
 #'     facet_var = species,
 #'     label_var = label, 
-#'     x_na = FALSE, 
+#'     x_na_rm = FALSE, 
 #'     pal_rev = TRUE)
 #'     
 gg_tile_col_facet <- function(data,
@@ -404,26 +414,27 @@ gg_tile_col_facet <- function(data,
                               subtitle_wrap = 75,
                               x_expand = c(0, 0),
                               x_labels = stringr::str_to_sentence,
-                              x_na = TRUE,
+                              x_na_rm = FALSE,
                               x_rev = FALSE,
                               x_title = NULL,
                               x_title_wrap = 50,
                               y_expand = c(0, 0),
                               y_labels = stringr::str_to_sentence,
-                              y_na = TRUE,
+                              y_na_rm = FALSE,
                               y_rev = FALSE,
                               y_title = NULL,
                               y_title_wrap = 50,
                               col_cuts = NULL,
+                              col_label_digits = NULL,
                               col_labels = NULL,
                               col_method = NULL,
-                              col_na = TRUE,
+                              col_na_rm = FALSE,
                               col_pretty_n = 5,
                               col_right_closed = TRUE,
                               col_title = NULL,
                               col_title_wrap = 25,
                               facet_labels = stringr::str_to_sentence,
-                              facet_na = TRUE,
+                              facet_na_rm = FALSE,
                               facet_ncol = NULL,
                               facet_nrow = NULL,
                               facet_scales = "fixed",
@@ -443,19 +454,19 @@ gg_tile_col_facet <- function(data,
   label_var <- rlang::enquo(label_var)
   text_var <- rlang::enquo(text_var)
   
-  if (x_na == FALSE) {
+  if (x_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!x_var))
   }
-  if (y_na == FALSE) {
+  if (y_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!y_var))
   }
-  if (col_na == FALSE) {
+  if (col_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!col_var))
   }
-  if (facet_na == FALSE) {
+  if (facet_na_rm == TRUE) {
     data <- data %>% 
       dplyr::filter(!is.na(!!facet_var))
   }
@@ -548,11 +559,18 @@ gg_tile_col_facet <- function(data,
       })
     }
 
-    if (is.null(col_labels)) col_labels <- scales::comma
-    
+    if (is.null(col_labels)) {
+      if (is.null(col_label_digits)) {
+        col_labels <- scales::comma
+      }
+      else {
+        col_labels <- scales::comma_format(accuracy = 10 ^ -col_label_digits)
+      }
+    }
+
     if (is.function(col_labels)) {
       data <- data %>% 
-        dplyr::mutate(dplyr::across(!!col_var, ~kimisc::cut_format(.x, col_cuts, 
+        dplyr::mutate(dplyr::across(!!col_var, ~cut_format(.x, col_cuts, 
                                                                    right = col_right_closed, 
                                                                    include.lowest = TRUE, 
                                                                    dig.lab = 50, 
